==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/java/ProjenrcOptions.java <==
package io.github.cdklabs.projen.java;

/**
 * (experimental) Options for `Projenrc`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.829Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.java.ProjenrcOptions")
@software.amazon.jsii.Jsii.Proxy(ProjenrcOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface ProjenrcOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) The name of the Java class which contains the `main()` method for projen.
     * <p>
     * Default: "projenrc"
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getClassName() {
        return null;
    }

    /**
     * (experimental) The projen version to use.
     * <p>
     * Default: - current version
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getProjenVersion() {
        return null;
    }

    /**
     * (experimental) Defines projenrc under the test scope instead of the main scope, which is reserved to the app.
     * <p>
     * This means that projenrc will be under
     * <code>src/test/java/projenrc.java</code> and projen will be defined as a test
     * dependency. This enforces that application code does not take a dependency
     * on projen code.
     * <p>
     * If this is disabled, projenrc should be under
     * <code>src/main/java/projenrc.java</code>.
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getTestScope() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ProjenrcOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ProjenrcOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<ProjenrcOptions> {
        java.lang.String className;
        java.lang.String projenVersion;
        java.lang.Boolean testScope;

        /**
         * Sets the value of {@link ProjenrcOptions#getClassName}
         * @param className The name of the Java class which contains the `main()` method for projen.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder className(java.lang.String className) {
            this.className = className;
            return this;
        }

        /**
         * Sets the value of {@link ProjenrcOptions#getProjenVersion}
         * @param projenVersion The projen version to use.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder projenVersion(java.lang.String projenVersion) {
            this.projenVersion = projenVersion;
            return this;
        }

        /**
         * Sets the value of {@link ProjenrcOptions#getTestScope}
         * @param testScope Defines projenrc under the test scope instead of the main scope, which is reserved to the app.
         *                  This means that projenrc will be under
         *                  <code>src/test/java/projenrc.java</code> and projen will be defined as a test
         *                  dependency. This enforces that application code does not take a dependency
         *                  on projen code.
         *                  <p>
         *                  If this is disabled, projenrc should be under
         *                  <code>src/main/java/projenrc.java</code>.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder testScope(java.lang.Boolean testScope) {
            this.testScope = testScope;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ProjenrcOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public ProjenrcOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ProjenrcOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ProjenrcOptions {
        private final java.lang.String className;
        private final java.lang.String projenVersion;
        private final java.lang.Boolean testScope;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.className = software.amazon.jsii.Kernel.get(this, "className", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.projenVersion = software.amazon.jsii.Kernel.get(this, "projenVersion", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.testScope = software.amazon.jsii.Kernel.get(this, "testScope", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.className = builder.className;
            this.projenVersion = builder.projenVersion;
            this.testScope = builder.testScope;
        }

        @Override
        public final java.lang.String getClassName() {
            return this.className;
        }

        @Override
        public final java.lang.String getProjenVersion() {
            return this.projenVersion;
        }

        @Override
        public final java.lang.Boolean getTestScope() {
            return this.testScope;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getClassName() != null) {
                data.set("className", om.valueToTree(this.getClassName()));
            }
            if (this.getProjenVersion() != null) {
                data.set("projenVersion", om.valueToTree(this.getProjenVersion()));
            }
            if (this.getTestScope() != null) {
                data.set("testScope", om.valueToTree(this.getTestScope()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.java.ProjenrcOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ProjenrcOptions.Jsii$Proxy that = (ProjenrcOptions.Jsii$Proxy) o;

            if (this.className != null ? !this.className.equals(that.className) : that.className != null) return false;
            if (this.projenVersion != null ? !this.projenVersion.equals(that.projenVersion) : that.projenVersion != null) return false;
            return this.testScope != null ? this.testScope.equals(that.testScope) : that.testScope == null;
        }

        @Override
        public final int hashCode() {
            int result = this.className != null ? this.className.hashCode() : 0;
            result = 31 * result + (this.projenVersion != null ? this.projenVersion.hashCode() : 0);
            result = 31 * result + (this.testScope != null ? this.testScope.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/java/ProjenrcOptions.java <==
package io.github.cdklabs.projen.java;

/**
 * (experimental) Options for <code>Projenrc</code>.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.494Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.java.ProjenrcOptions")
@software.amazon.jsii.Jsii.Proxy(ProjenrcOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface ProjenrcOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) The name of the Java class which contains the <code>main()</code> method for projen.
     * <p>
     * Default: "projenrc"
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getClassName() {
        return null;
    }

    /**
     * (experimental) The projen version to use.
     * <p>
     * Default: - current version
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getProjenVersion() {
        return null;
    }

    /**
     * (experimental) Defines projenrc under the test scope instead of the main scope, which is reserved to the app.
     * <p>
     * This means that projenrc will be under
     * <code>src/test/java/projenrc.java</code> and projen will be defined as a test
     * dependency. This enforces that application code does not take a dependency
     * on projen code.
     * <p>
     * If this is disabled, projenrc should be under
     * <code>src/main/java/projenrc.java</code>.
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getTestScope() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ProjenrcOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ProjenrcOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<ProjenrcOptions> {
        java.lang.String className;
        java.lang.String projenVersion;
        java.lang.Boolean testScope;

        /**
         * Sets the value of {@link ProjenrcOptions#getClassName}
         * @param className The name of the Java class which contains the <code>main()</code> method for projen.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder className(java.lang.String className) {
            this.className = className;
            return this;
        }

        /**
         * Sets the value of {@link ProjenrcOptions#getProjenVersion}
         * @param projenVersion The projen version to use.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder projenVersion(java.lang.String projenVersion) {
            this.projenVersion = projenVersion;
            return this;
        }

        /**
         * Sets the value of {@link ProjenrcOptions#getTestScope}
         * @param testScope Defines projenrc under the test scope instead of the main scope, which is reserved to the app.
         *                  This means that projenrc will be under
         *                  <code>src/test/java/projenrc.java</code> and projen will be defined as a test
         *                  dependency. This enforces that application code does not take a dependency
         *                  on projen code.
         *                  <p>
         *                  If this is disabled, projenrc should be under
         *                  <code>src/main/java/projenrc.java</code>.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder testScope(java.lang.Boolean testScope) {
            this.testScope = testScope;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ProjenrcOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public ProjenrcOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ProjenrcOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ProjenrcOptions {
        private final java.lang.String className;
        private final java.lang.String projenVersion;
        private final java.lang.Boolean testScope;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.className = software.amazon.jsii.Kernel.get(this, "className", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.projenVersion = software.amazon.jsii.Kernel.get(this, "projenVersion", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.testScope = software.amazon.jsii.Kernel.get(this, "testScope", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.className = builder.className;
            this.projenVersion = builder.projenVersion;
            this.testScope = builder.testScope;
        }

        @Override
        public final java.lang.String getClassName() {
            return this.className;
        }

        @Override
        public final java.lang.String getProjenVersion() {
            return this.projenVersion;
        }

        @Override
        public final java.lang.Boolean getTestScope() {
            return this.testScope;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getClassName() != null) {
                data.set("className", om.valueToTree(this.getClassName()));
            }
            if (this.getProjenVersion() != null) {
                data.set("projenVersion", om.valueToTree(this.getProjenVersion()));
            }
            if (this.getTestScope() != null) {
                data.set("testScope", om.valueToTree(this.getTestScope()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.java.ProjenrcOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ProjenrcOptions.Jsii$Proxy that = (ProjenrcOptions.Jsii$Proxy) o;

            if (this.className != null ? !this.className.equals(that.className) : that.className != null) return false;
            if (this.projenVersion != null ? !this.projenVersion.equals(that.projenVersion) : that.projenVersion != null) return false;
            return this.testScope != null ? this.testScope.equals(that.testScope) : that.testScope == null;
        }

        @Override
        public final int hashCode() {
            int result = this.className != null ? this.className.hashCode() : 0;
            result = 31 * result + (this.projenVersion != null ? this.projenVersion.hashCode() : 0);
            result = 31 * result + (this.testScope != null ? this.testScope.hashCode() : 0);
            return result;
        }
    }
}
